@@ -4,15 +4,12 @@
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
+    QApplication::setApplicationName("enhanced-lockscreen");
+    QApplication::setOrganizationName("MohammadAG");
+    QApplication::setApplicationVersion("0.2");
     MainWindow w;
-#if 0
-#if defined(Q_WS_S60)
-    w.showMaximized();
-#elif defined(Q_WS_MAEMO_5)
-    w.showFullScreen();
-#else
+#ifndef Q_WS_MAEMO_5
     w.show();
-#endif
 #endif
 
     return a.exec();
