@@ -9,6 +9,10 @@
 #include <QDateTime>
 #include <QTimer>
 #include <QDesktopWidget>
+#include <QSettings>
+#include <QString>
+#include <QPalette>
+#include <QDebug>
 #include <backends/systemplayer.h>
 #ifdef Q_WS_MAEMO_5
     #include <QDBusInterface>
@@ -35,8 +39,10 @@ protected:
 private:
     Ui::MainWindow *ui;
     QString m_tklockState;
+    QString m_imageUrl;
     bool m_isCallActive;
     SystemPlayer *m_player;
+    SystemPlayer::PlaybackState m_state;
     void connectSignals();
 
 private slots:
@@ -49,6 +55,11 @@ private slots:
     void onPlayButtonClicked();
     void onMetadataChanged(QMap<QString,QVariant>);
     void onCallStateChanged(QString state);
+    void sliderValueChanged(int value);
+    void prevButtonPressed();
+    void nextButtonPressed();
+    void playButtonPressed();
+    void orientationChanged();
 };
 
 #endif // MAINWINDOW_H
